Class: Aws::Macie::Types::ClassificationTypeUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-macie/types.rb

Overview

(Discontinued) The classification type that Amazon Macie Classic applies to the associated S3 resources. At least one of the classification types (oneTime or continuous) must be specified.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#continuousString

(Discontinued) A continuous classification of the objects that are added to a specified S3 bucket. Amazon Macie Classic begins performing continuous classification after a bucket is successfully associated with Macie Classic.

Returns:

  • (String)


120
121
122
123
124
125
# File 'lib/aws-sdk-macie/types.rb', line 120

class ClassificationTypeUpdate < Struct.new(
  :one_time,
  :continuous)
  SENSITIVE = []
  include Aws::Structure
end

#one_timeString

(Discontinued) A one-time classification of all of the existing objects in a specified S3 bucket.

Returns:

  • (String)


120
121
122
123
124
125
# File 'lib/aws-sdk-macie/types.rb', line 120

class ClassificationTypeUpdate < Struct.new(
  :one_time,
  :continuous)
  SENSITIVE = []
  include Aws::Structure
end