Class: Aws::Macie::Types::ListS3ResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Macie::Types::ListS3ResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-macie/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
(Discontinued) Use this parameter to indicate the maximum number of items that you want in the response.
-
#member_account_id ⇒ String
(Discontinued) The Amazon Macie Classic member account ID whose associated S3 resources you want to list.
-
#next_token ⇒ String
(Discontinued) Use this parameter when paginating results.
Instance Attribute Details
#max_results ⇒ Integer
(Discontinued) Use this parameter to indicate the maximum number of items that you want in the response. The default value is 250.
331 332 333 334 335 336 337 |
# File 'lib/aws-sdk-macie/types.rb', line 331 class ListS3ResourcesRequest < Struct.new( :member_account_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#member_account_id ⇒ String
(Discontinued) The Amazon Macie Classic member account ID whose associated S3 resources you want to list.
331 332 333 334 335 336 337 |
# File 'lib/aws-sdk-macie/types.rb', line 331 class ListS3ResourcesRequest < Struct.new( :member_account_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
(Discontinued) Use this parameter when paginating results. Set its
value to null on your first call to the ListS3Resources action.
Subsequent calls to the action fill nextToken in the request with
the value of nextToken from the previous response to continue
listing data.
331 332 333 334 335 336 337 |
# File 'lib/aws-sdk-macie/types.rb', line 331 class ListS3ResourcesRequest < Struct.new( :member_account_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |